@@ -39,7 +39,8 @@ public:
  * MP3 encoder using the LAME encoder.
  * Go to https://lame.sourceforge.io/ for more information.
  */
-class EncoderLame : public QObject, public AudioCDEncoder {
+class EncoderLame : public QObject, public AudioCDEncoder
+{
     Q_OBJECT
 
 public:
